export default {
    "message": "Unexpected token *",
    "column": 15,
    "index": 14,
    "lineNumber": 1
}